Family Object — Map of Objects

Skip to main content
`Ctrl`+`K`

# Family Object

class Family(culture_id: str | None = None, family_id: str = 'none', params: dict | None = None, size: int = 1, label: str | None = None, color: str = 'black', alpha: float = 1.0, ms: int = 20, show: bool = True, marker: str = 'o', starting_from: int = 0, single: bool = False, instance_ids: list | None = None, path: dict | None = None, **kwargs)

  Abstract family of instances: a set of instances from the same culture